![https://yk-website-images.s3.eu-west-1.amazonaws.com/LogoV4_TRANSPARENT.png](https://yk-website-images.s3.eu-west-1.amazonaws.com/LogoV4_TRANSPARENT.png)

# YooniK Utils package for python

[![PyPi Version](https://img.shields.io/pypi/v/yk_utils.svg)](https://pypi.org/project/yk-utils/)
[![License](https://img.shields.io/pypi/l/yk_utils.svg)](https://github.com/dev-yoonik/yk-utils-python/blob/master/LICENSE)

This repository contains helper functions and classes for [YooniK](https://www.yoonik.me) products in Python.

## Getting started

Install the module using [pip](https://pypi.python.org/pypi/pip/):

```bash
pip install yk_utils
```

### Installing from the source code

```bash
python setup.py install
```

## Contact & Support

For more information please [contact us](mailto:tech@yoonik.me) or join us at our [discord community](https://discord.gg/SqHVQUFNtN).
